Date: 01 4, 2002 11:22:57 AM

# unknown

## Purpose

Pre action that succeeds if leaf token is an unknown word.

## Syntax

<fromRuleEltNumber,toRuleEltNumber>unknown();

fromRuleEltNumber - type: int
toRuleEltNumber - type: int

## Returns

## Remarks

This action is meaningful only if a prior pass has performed the CODE Action lookup().

This mechanism is somewhat obsolete. Use the function spellword instead.

## Example

## See Also

lookup, PRE Actions, spellword